@@ -36,11 +36,22 @@ class GraphQLWSProtocol(protocol.GraphQLWSProtocol):
 
     # GraphQL engine implementation.
 
-    def get_stream(self, opid: str, payload: dict) -> typing.AsyncGenerator:
+    def get_subscription(
+        self, opid: str, payload: protocol.Payload
+    ) -> protocol.Subscription:
         context = {**payload.get("context", {}), **self.context}
-        return self.engine.subscribe(
-            query=payload.get("query"),
+        aiterator = self.engine.subscribe(
+            query=payload["query"],
             variables=payload.get("variables"),
             operation_name=payload.get("operationName"),
             context=context,
         )
+
+        # `tartiflette` type hints say it returns an `AsyncIterable` (doesn't
+        # include `aclose`), but it is actually a full-fledged `AsyncGenerator`
+        # which we want to be closing at some point.
+        agen = typing.cast(
+            typing.AsyncGenerator[typing.Dict[str, typing.Any], None], aiterator
+        )
+
+        return protocol.Subscription(agen)
